@@ -21,7 +21,7 @@ module Text.PrettyPrint.Leijen.Text.Monadic (
    Doc, -- putDoc, hPutDoc,
 
    -- * Basic combinators
-   empty, char, text, textStrict, (<>), nest, line, linebreak, group, softline,
+   empty, char, text, textStrict, beside, nest, line, linebreak, group, softline,
    softbreak, spacebreak,
 
    -- * Alignment
@@ -70,25 +70,22 @@ module Text.PrettyPrint.Leijen.Text.Monadic (
    ) where
 
 import Prelude ()
+
 import Prelude.Compat hiding ((<$>))
 
-
-import           Text.PrettyPrint.Leijen.Text (Doc, Pretty (..), SimpleDoc (..),
-                                               displayB, displayIO, displayT, displayTStrict,
-                                               hPutDoc, putDoc, renderCompact,
-                                               renderOneLine, renderPretty)
+import           Text.PrettyPrint.Leijen.Text (Doc, Pretty(..), SimpleDoc(..),
+                                               displayB, displayIO, displayT,
+                                               displayTStrict, hPutDoc, putDoc,
+                                               renderCompact, renderOneLine,
+                                               renderPretty)
 import qualified Text.PrettyPrint.Leijen.Text as PP
 
-import Control.Applicative (liftA2, liftA3)
-import Data.String    (IsString (..))
-import qualified Data.Text as TS
-import Data.Text.Lazy (Text)
+import           Control.Applicative (liftA2, liftA3)
+import qualified Data.Text           as TS
+import           Data.Text.Lazy      (Text)
 
 infixr 5 </>,<//>,<$>,<$$>
-infixr 6 <>,<+>,<++>
-
-instance (Applicative m) => IsString (m Doc) where
-    fromString = string . fromString
+infixr 6 <+>,<++>,`beside`
 
 -----------------------------------------------------------
 
@@ -251,11 +248,11 @@ hcat = fmap PP.hcat
 vcat :: (Functor m) => m [Doc] -> m Doc
 vcat = fmap PP.vcat
 
--- | The document @(x \<\> y)@ concatenates document @x@ and document
---   @y@. It is an associative operation having 'empty' as a left and
---   right unit.  (infixr 6)
-(<>) :: (Applicative m) => m Doc -> m Doc -> m Doc
-(<>) = liftA2 (PP.<>)
+-- | The document @(x `beside` y)@ concatenates document @x@ and
+--   document @y@. It is an associative operation having 'empty' as a
+--   left and right unit.  (infixr 6)
+beside :: (Applicative m) => m Doc -> m Doc -> m Doc
+beside = liftA2 (PP.beside)
 
 -- | The document @(x \<+\> y)@ concatenates document @x@ and @y@ with
 --   a 'space' in between.  (infixr 6)
@@ -337,9 +334,9 @@ brackets :: (Functor m) => m Doc -> m Doc
 brackets = fmap PP.brackets
 
 -- | The document @(enclose l r x)@ encloses document @x@ between
---   documents @l@ and @r@ using @(\<\>)@.
+--   documents @l@ and @r@ using @'beside'@.
 --
---   > enclose l r x = l <> x <> r
+--   > enclose l r x = l `beside` x `beside` r
 enclose :: (Applicative m) => m Doc -> m Doc -> m Doc -> m Doc
 enclose = liftA3 PP.enclose
 
@@ -397,7 +394,7 @@ comma = pure PP.comma
 
 -- | The document @space@ contains a single space, \" \".
 --
--- > x <+> y = x <> space <> y
+-- > x <+> y = x `beside` space `beside` y
 space :: (Applicative m) => m Doc
 space = pure PP.space
 
